exceptiontools.LilyPondParserError
==================================

.. abjad-lineage:: abjad.tools.exceptiontools.LilyPondParserError.LilyPondParserError

.. autoclass:: abjad.tools.exceptiontools.LilyPondParserError.LilyPondParserError

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.exceptiontools.LilyPondParserError.LilyPondParserError.__delattr__
      ~abjad.tools.exceptiontools.LilyPondParserError.LilyPondParserError.__getitem__
      ~abjad.tools.exceptiontools.LilyPondParserError.LilyPondParserError.__getslice__
      ~abjad.tools.exceptiontools.LilyPondParserError.LilyPondParserError.__repr__
      ~abjad.tools.exceptiontools.LilyPondParserError.LilyPondParserError.__setattr__
      ~abjad.tools.exceptiontools.LilyPondParserError.LilyPondParserError.__str__
      ~abjad.tools.exceptiontools.LilyPondParserError.LilyPondParserError.__unicode__

Bases
-----

- :py:class:`exceptions.Exception <exceptions.Exception>`

- :py:class:`exceptions.BaseException <exceptions.BaseException>`

- :py:class:`__builtin__.object <object>`

Special methods
---------------

.. automethod:: abjad.tools.exceptiontools.LilyPondParserError.LilyPondParserError.__delattr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.LilyPondParserError.LilyPondParserError.__getitem__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.LilyPondParserError.LilyPondParserError.__getslice__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.LilyPondParserError.LilyPondParserError.__repr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.LilyPondParserError.LilyPondParserError.__setattr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.LilyPondParserError.LilyPondParserError.__str__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.LilyPondParserError.LilyPondParserError.__unicode__
   :noindex:
